summaryrefslogtreecommitdiff
path: root/lib/CodeGen/MachineModuleInfo.cpp
diff options
context:
space:
mode:
authorEvan Cheng <evan.cheng@apple.com>2008-02-01 02:05:57 +0000
committerEvan Cheng <evan.cheng@apple.com>2008-02-01 02:05:57 +0000
commita647c92ec2b3c91e1e6de25cc5c7860912c7626b (patch)
treef907c698533d98e2b0d0e7eda9e3396ec56a29b7 /lib/CodeGen/MachineModuleInfo.cpp
parentec3e5c8a39c3dae7457d0eb18f98685decb23fcd (diff)
downloadllvm-a647c92ec2b3c91e1e6de25cc5c7860912c7626b.tar.gz
llvm-a647c92ec2b3c91e1e6de25cc5c7860912c7626b.tar.bz2
llvm-a647c92ec2b3c91e1e6de25cc5c7860912c7626b.tar.xz
Rename RecordLabel to RecordSourceLine because that's what it is doing.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@46628 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/CodeGen/MachineModuleInfo.cpp')
-rw-r--r--lib/CodeGen/MachineModuleInfo.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/CodeGen/MachineModuleInfo.cpp b/lib/CodeGen/MachineModuleInfo.cpp
index 12680a0e9c..5edeefbfae 100644
--- a/lib/CodeGen/MachineModuleInfo.cpp
+++ b/lib/CodeGen/MachineModuleInfo.cpp
@@ -1611,11 +1611,11 @@ MachineModuleInfo::getGlobalVariablesUsing(Module &M,
return ::getGlobalVariablesUsing(M, RootName);
}
/// RecordLabel - Records location information and associates it with a
/// debug label. Returns a unique label ID used to generate a label and
/// provide correspondence to the source line list.
-unsigned MachineModuleInfo::RecordLabel(unsigned Line, unsigned Column,
- unsigned Source) {
+unsigned MachineModuleInfo::RecordSourceLine(unsigned Line, unsigned Column,
+ unsigned Source) {
unsigned ID = NextLabelID();
Lines.push_back(SourceLineInfo(Line, Column, Source, ID));
return ID;
@@ -1611,11 +1611,11 @@ MachineModuleInfo::getGlobalVariablesUsing(Module &M,
return ::getGlobalVariablesUsing(M, RootName);
}
-/// RecordLabel - Records location information and associates it with a
+/// RecordSourceLine - Records location information and associates it with a
/// debug label. Returns a unique label ID used to generate a label and
/// provide correspondence to the source line list.